==> reactor-excel-1.0.3-sources.jar: org/hswebframework/reactor/excel/converter/SimpleWritableCell.java <==
package org.hswebframework.reactor.excel.converter;

import lombok.Getter;
import org.hswebframework.reactor.excel.Cell;
import org.hswebframework.reactor.excel.CellDataType;
import org.hswebframework.reactor.excel.ExcelHeader;
import org.hswebframework.reactor.excel.WritableCell;

import java.util.Optional;

public class SimpleWritableCell implements WritableCell {

    private CellDataType type;

    public Object value;

    @Getter
    private long rowIndex;

    @Getter
    private int columnIndex;

    @Getter
    private boolean endOfRow;

    @Getter
    private int sheetIndex;

    public SimpleWritableCell(ExcelHeader header, Object value, long rowIndex, int columnIndex, boolean endOfRow, int sheetIndex) {
        this(header.getType(), value, rowIndex, columnIndex, endOfRow, sheetIndex);
    }

    public SimpleWritableCell(CellDataType dataType, Object value, long rowIndex, int columnIndex, boolean endOfRow, int sheetIndex) {
        this.type = dataType;
        this.value = value;
        this.rowIndex = rowIndex;
        this.columnIndex = columnIndex;
        this.endOfRow = endOfRow;
        this.sheetIndex = sheetIndex;
    }

    public SimpleWritableCell(Cell cell, int sheetIndex) {
        this(cell.getType(),
             cell.value().orElse(null),
             cell.getRowIndex(),
             cell.getColumnIndex(),
             cell.isEndOfRow(),
             sheetIndex);
    }


    @Override
    public Optional<Object> value() {
        return Optional.ofNullable(value);
    }

    @Override
    public CellDataType getType() {
        return type;
    }
}

==> reactor-excel-1.0.5-sources.jar: org/hswebframework/reactor/excel/converter/SimpleWritableCell.java <==
package org.hswebframework.reactor.excel.converter;

import lombok.Getter;
import org.hswebframework.reactor.excel.*;

import java.util.Optional;

public class SimpleWritableCell implements WritableCell, OptionSupport {

    private final CellDataType type;

    public Object value;

    @Getter
    private final long rowIndex;

    @Getter
    private final int columnIndex;

    @Getter
    private final boolean endOfRow;

    @Getter
    private final int sheetIndex;

    private final Options options = Options.of();

    @Override
    public Options options() {
        return options;
    }

    public SimpleWritableCell(ExcelHeader header, Object value, long rowIndex, int columnIndex, boolean endOfRow, int sheetIndex) {
        this(header.getType(), value, rowIndex, columnIndex, endOfRow, sheetIndex);
    }

    public SimpleWritableCell(CellDataType dataType, Object value, long rowIndex, int columnIndex, boolean endOfRow, int sheetIndex) {
        this.type = dataType;
        this.value = value;
        this.rowIndex = rowIndex;
        this.columnIndex = columnIndex;
        this.endOfRow = endOfRow;
        this.sheetIndex = sheetIndex;
    }

    public SimpleWritableCell(Cell cell, int sheetIndex) {
        this(cell.getType(),
             cell.value().orElse(null),
             cell.getRowIndex(),
             cell.getColumnIndex(),
             cell.isEndOfRow(),
             sheetIndex);
        if (cell instanceof WritableCell) {
            this.options().merge(((WritableCell) cell).options());
        }
    }


    @Override
    public Optional<Object> value() {
        return Optional.ofNullable(value);
    }

    @Override
    public CellDataType getType() {
        return type;
    }
}
